.. lc_ld documentation master file, created by
   sphinx-quickstart on Wed Aug 27 16:18:43 2025.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to documentation for loc-authorities!
=================================

**loc-authorities** is a Python library for querying authorities from the `Linked Data Service <https://id.loc.gov/>`_ provided by the Library of Congress. It provides methods for querying the search and retrieval APIs and also provides Python classes to represent entities from the Linked Data Service.

.. note::
   This project is under active development.
   The developers of this project have no relationship to the United States government or the Library of Congress.

.. toctree::
   :maxdepth: 2
   
   getting-started
   api-reference